pub enum MonthName {
January,
February,
March,
April,
May,
June,
July,
August,
September,
October,
November,
December,
}Expand description
The name of a calendar month, as extracted from natural language input.
Conversions
MonthName can be constructed from either a string or a number:
use partial_date::models::{MonthName, MonthNameError};
use std::convert::TryFrom;
// From a name string (full, abbreviated, or unambiguous prefix)
assert_eq!(MonthName::try_from("October"), Ok(MonthName::October));
assert_eq!(MonthName::try_from("oct"), Ok(MonthName::October));
assert_eq!(MonthName::try_from("Octo"), Ok(MonthName::October));
// From a numeric string
assert_eq!(MonthName::try_from("10"), Ok(MonthName::October));
// From a u8
assert_eq!(MonthName::try_from(10_u8), Ok(MonthName::October));
// Errors
assert_eq!(MonthName::try_from(0_u8), Err(MonthNameError::NumberOutOfRange(0)));
assert_eq!(MonthName::try_from(13_u8), Err(MonthNameError::NumberOutOfRange(13)));
assert_eq!(MonthName::try_from("Xyz"), Err(MonthNameError::UnrecognisedName));
assert_eq!(MonthName::try_from("5x"), Err(MonthNameError::NotAMonth));Variants
Implementations